/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*  This is source code for the PSoC 4 BLE Find Me Profile Target example project.
*
* Note:
*
* Owners:
*  OLEG@CYPRESS.COM, KRIS@CYPRESS.COM
*
* Related Document:
*
* Hardware Dependency:
*  1. PSoC 4 BLE device
*  2. CY8CKIT-042 BLE Pioneer Kit
*
* Code Tested With:
*  1. PSoC Creator 3.1
*  2. ARM CM3-RVDS
*  3. ARM CM3-GCC
*  4. ARM CM3-MDK
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include <project.h>
//#include <stdio.h>


/***************************************
*        API Constants
***************************************/

#define LED_ON             (0u)
#define LED_OFF            (1u)
#define TRUE			   (1u)		
#define FALSE			   (0u)		

/* KRIS_UPDATE - Extern and constants required for dynamic ADV payload update */
#define ENABLE_DYNAMIC_ADV          (1u)

#if ENABLE_DYNAMIC_ADV
extern CYBLE_GAPP_DISC_MODE_INFO_T cyBle_discoveryModeInfo;
#define BATTERY_SERVICE_DATA_INDEX  (11u)
#define LOOP_DELAY                  (1u)
#define advPayload                  (cyBle_discoveryModeInfo.advData->advData)

#endif

/***************************************
*        Function Prototypes
***************************************/
void StackEventHandler(uint32 event, void* eventParam);
void Set32ByPtr(uint8 ptr[], uint32 value);
CY_ISR_PROTO(SwitchISR);

/***************************************
*        Global variables
***************************************/
uint8 temp_data[5] = {0u, 0u, 0u, 0u, 0u};
int32 temperatureValue;

// *********************

void Set32ByPtr(uint8 ptr[], uint32 value)
{
    ptr[0u] = (uint8) value;
    ptr[1u] = (uint8) (value >> 8u);    
    ptr[2u] = (uint8) (value >> 16u);    
    ptr[3u] = (uint8) (value >> 24u);
}

CY_ISR(SwitchISR)
{
	//Switch_Interrupt_ClearPending();
	User_Switch_ClearInterrupt();
    
    uint8 PB_Status;
    uint8 Old_PB_Status;
    uint8 New_PB_Status;
    
    // Check spikes
    // store first value
    Old_PB_Status = User_Switch_Read();
     CyDelayUs(50);
    // read again
    New_PB_Status = User_Switch_Read();
    
    if( New_PB_Status == Old_PB_Status)
        {
           PB_Status = New_PB_Status;            
        }   
    else
        {
            return;            
        }
    // check status    
    if (PB_Status == TRUE )
    {        
        LED1_Write(1);         
        temperatureValue = 50u;              
    }
    else
    {      
       LED1_Write(0);
       temperatureValue = 0u;     
    } 
    /* Convert int32 to the IEEE-11073 FLOAT-Type.
        *  It is defined as a 32-bit value with a 24-bit mantissa and an 8-bit exponent.
        *  For the integer temperature, 24-bit value has been used with mantissa equal to 0 */
        temperatureValue &= 0x00FFFFFF;

        /* Copy temperature to array */
        Set32ByPtr(temp_data + 1u, (uint32)temperatureValue);
        
     /* Send temperature to client */ 
    CyBle_HtssSendIndication(cyBle_connHandle, CYBLE_HTS_TEMP_MEASURE,  sizeof(temp_data), temp_data);
        
}




/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Main function.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main()
{
    CYBLE_API_RESULT_T apiResult;
    uint16 count = 0;
    uint8 batteryLevel = 100;
  // Systm initialization function.
    CyGlobalIntEnable;

    apiResult = CyBle_Start(StackEventHandler);

    if(apiResult != CYBLE_ERROR_OK)
    {
        /* BLE stack initialization failed, check your configuration */
        CYASSERT(0);
    }

    //CyBle_IasRegisterAttrCallback(IasEventHandler);

     // start interrupt 
    Switch_Interrupt_StartEx(SwitchISR);
    
    for(;;)
    {
        CYBLE_STATE_T bleState;

        /* Single API call to service all the BLE stack events. Must be
         * called at least once in a BLE connection interval */
        CyBle_ProcessEvents();

        bleState = CyBle_GetState();

        if(bleState != CYBLE_STATE_STOPPED &&
            bleState != CYBLE_STATE_INITIALIZING)
        {
            /* Configure BLESS in DeepSleep mode  */
            CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);

            /* Configure PSoC 4 BLE system in sleep mode */
            CySysPmSleep();

            /* BLE link layer timing interrupt will wake up the system */
        }
        
        /* KRIS_UPDATE - Dynamic advertisement payload update code */
        /*-----------------------------------------------------------------*/
    #if ENABLE_DYNAMIC_ADV        
        count++; /* Loop counter */
        
        /* Make sure the BLE sub-system is not in connected state. Once the system enters sleep mode during
         * advertisement, the source of wake-up is the advertisement timeout timer which has a wakeup interval
         * of 1 advertisement (ADV) interval (25ms). LOOP_DELAY * ADV interval is the interval after which ADV 
         * data is updated in this firmware.*/
        if(bleState != CYBLE_STATE_CONNECTED && count >= LOOP_DELAY && CyBle_GetBleSsState() == CYBLE_BLESS_STATE_EVENT_CLOSE)
        {
            advPayload[BATTERY_SERVICE_DATA_INDEX] = batteryLevel--;
            apiResult = CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
            /* Handle erros condition for start advertisement here */
            
            count = 0;
            
            if(batteryLevel == 0)
            {
                batteryLevel = 100;
            }
            
            CyBle_GapUpdateAdvData(cyBle_discoveryModeInfo.advData, cyBle_discoveryModeInfo.scanRspData);
        }
    #endif        
        /*-----------------------------------------------------------------*/
    }
}


/*******************************************************************************
* Function Name: StackEventHandler
********************************************************************************
*
* Summary:
*  This is an event callback function to receive events from the BLE Component.
*
* Parameters:
*  uint8 event:       Event from the CYBLE component
*  void* eventParams: A structure instance for corresponding event type. The
*                     list of event structure is described in the component
*                     datasheet.
*
* Return:
*  None
*
*******************************************************************************/
void StackEventHandler(uint32 event, void *eventParam)
{
    switch(event)
    {
        /* Mandatory events to be handled by Find Me Target design */
        case CYBLE_EVT_STACK_ON:
        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED:
            /* Start BLE advertisement for 30 seconds and update link
             * status on LEDs */
            CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
            
          break;

        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
          
        break;
        
        /**********************************************************
        *                       GAP Events
        ***********************************************************/
        case CYBLE_EVT_GAP_AUTH_REQ:
            break;

        case CYBLE_EVT_GAP_PASSKEY_ENTRY_REQUEST:
            break;

        case CYBLE_EVT_GAP_PASSKEY_DISPLAY_REQUEST:
            break;

        case CYBLE_EVT_GAP_AUTH_COMPLETE:

            break;
        case CYBLE_EVT_GAP_AUTH_FAILED:

        case CYBLE_EVT_GAPP_ADVERTISEMENT_START_STOP:
            if(CyBle_GetState() == CYBLE_STATE_DISCONNECTED)
            {
                /* Advertisement event timed out, go to low power
                 * mode (Hibernate mode) and wait for an external
                 * user event to wake up the device again */
               
                Wakeup_SW_ClearInterrupt();
                Wakeup_Interrupt_ClearPending();
                Wakeup_Interrupt_Start();
                CySysPmHibernate();
            }
            break;

        /**********************************************************
        *                       GATT Events
        ***********************************************************/
        case CYBLE_EVT_GATT_CONNECT_IND:
            break;

        case CYBLE_EVT_GATT_DISCONNECT_IND:
            break;

        case CYBLE_EVT_GATTS_XCNHG_MTU_REQ:
        break;

        default:
        break;
    }
}





/* [] END OF FILE */
